bouncer.core

The core namespace provides the two main entry point functions in bouncer:

  • validate
  • valid?

All other functions are meant for internal use only and shouldn't be relied upon.

The project README should get you started, it's pretty comprehensive.

If you'd like to know more about the motivation behind bouncer, check the announcement post.

The `core` namespace provides the two main entry point functions in bouncer:

  - `validate`
  - `valid?`


All other functions are meant for internal use only and shouldn't be relied upon.

The project [README](https://github.com/leonardoborges/bouncer/blob/master/README.md) should get you started,
it's pretty comprehensive.


If you'd like to know more about the motivation behind `bouncer`, check the
[announcement post](http://www.leonardoborges.com/writings/2013/01/04/bouncer-validation-lib-for-clojure/).
raw docstring

bouncer.validators

This namespace contains all built-in validators as well as macros for defining new validators and validator sets

This namespace contains all built-in validators as well as
macros for defining new validators and validator sets
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries